pub struct Dashboard { /* private fields */ }Expand description
Stateful Ratatui dashboard model.
Implementations
Sourceimpl Dashboard
impl Dashboard
Sourcepub fn set_history(&mut self, history: Vec<SessionHistoryEntry>)
pub fn set_history(&mut self, history: Vec<SessionHistoryEntry>)
Replace the recent history list.
Sourcepub fn insert_history_session(&mut self, session: SessionState)
pub fn insert_history_session(&mut self, session: SessionState)
Insert or replace a session loaded from history.
Sourcepub fn apply_event(&mut self, event: &SessionEvent, max_logs: usize)
pub fn apply_event(&mut self, event: &SessionEvent, max_logs: usize)
Apply a new runtime event to the dashboard state.
Sourcepub fn handle_key(&mut self, key: KeyEvent) -> Option<UiAction>
pub fn handle_key(&mut self, key: KeyEvent) -> Option<UiAction>
Handle a keyboard event and return any requested app-layer action.